@@ -78,7 +78,7 @@ asn1c_emit_constraint_checking_code(arg_t *arg) {
 			produce_st = 1;
 		break;
 	case ASN_BASIC_REAL:
-		if(!(arg->flags & A1C_USE_NATIVE_TYPES))
+		if((arg->flags & A1C_USE_WIDE_TYPES))
 			produce_st = 1;
 		break;
 	case ASN_BASIC_BIT_STRING:
@@ -130,7 +130,7 @@ asn1c_emit_constraint_checking_code(arg_t *arg) {
 	 */
 	OUT("if(!sptr) {\n");
 		INDENT(+1);
-		OUT("_ASN_CTFAIL(app_key, td, sptr,\n");
+		OUT("ASN__CTFAIL(app_key, td, sptr,\n");
 		OUT("\t\"%%s: value not given (%%s:%%d)\",\n");
 		OUT("\ttd->name, __FILE__, __LINE__);\n");
 		OUT("return -1;\n");
@@ -215,7 +215,7 @@ asn1c_emit_constraint_checking_code(arg_t *arg) {
 		INDENT(-1);
 	OUT("} else {\n");
 		INDENT(+1);
-			OUT("_ASN_CTFAIL(app_key, td, sptr,\n");
+			OUT("ASN__CTFAIL(app_key, td, sptr,\n");
 			OUT("\t\"%%s: constraint failed (%%s:%%d)\",\n");
 			OUT("\ttd->name, __FILE__, __LINE__);\n");
 			OUT("return -1;\n");
@@ -315,7 +315,7 @@ asn1c_emit_constraint_tables(arg_t *arg, int got_size) {
 
 		untl = (range_stop - range_start) + 1;
 		untl += (untl % 16)?16 - (untl % 16):0;
-		OUT("static int permitted_alphabet_table_%d[%d] = {\n",
+		OUT("static const int permitted_alphabet_table_%d[%d] = {\n",
 			arg->expr->_type_unique_index, max_table_size);
 		for(n = 0; n < untl; n++) {
 			cardinal += table[n] ? 1 : 0;
@@ -347,7 +347,7 @@ asn1c_emit_constraint_tables(arg_t *arg, int got_size) {
 		if((arg->flags & A1C_GEN_PER)
 		&& (etype & ASN_STRING_KM_MASK)) {
 		    int c;
-		    OUT("static int permitted_alphabet_code2value_%d[%d] = {\n",
+		    OUT("static const int permitted_alphabet_code2value_%d[%d] = {\n",
 			arg->expr->_type_unique_index, cardinal);
 		    for(n = c = 0; c < max_table_size; c++) {
 			if(table[c]) {
@@ -396,7 +396,7 @@ asn1c_emit_constraint_tables(arg_t *arg, int got_size) {
 		OUT("\n");
 	} else {
 		if(use_table) {
-			OUT("int *table = permitted_alphabet_table_%d;\n",
+			OUT("const int *table = permitted_alphabet_table_%d;\n",
 				arg->expr->_type_unique_index);
 			emit_alphabet_check_loop(arg, 0);
 		} else {
@@ -567,7 +567,7 @@ emit_size_determination_code(arg_t *arg, asn1p_expr_type_e etype) {
 	case ASN_STRING_UTF8String:
 		OUT("size = UTF8String_length(st);\n");
 		OUT("if((ssize_t)size < 0) {\n");
-		OUT("\t_ASN_CTFAIL(app_key, td, sptr,\n");
+		OUT("\tASN__CTFAIL(app_key, td, sptr,\n");
 		OUT("\t\t\"%%s: UTF-8: broken encoding (%%s:%%d)\",\n");
 		OUT("\t\ttd->name, __FILE__, __LINE__);\n");
 		OUT("\treturn -1;\n");
@@ -637,7 +637,7 @@ emit_value_determination_code(arg_t *arg, asn1p_expr_type_e etype, asn1cnst_rang
 				/* Special case for treating unsigned longs */
 				OUT("if(asn_INTEGER2ulong(st, &value)) {\n");
 				INDENT(+1);
-				OUT("_ASN_CTFAIL(app_key, td, sptr,\n");
+				OUT("ASN__CTFAIL(app_key, td, sptr,\n");
 				OUT("\t\"%%s: value too large (%%s:%%d)\",\n");
 				OUT("\ttd->name, __FILE__, __LINE__);\n");
 				OUT("return -1;\n");
@@ -646,7 +646,7 @@ emit_value_determination_code(arg_t *arg, asn1p_expr_type_e etype, asn1cnst_rang
 			} else {
 				OUT("if(asn_INTEGER2long(st, &value)) {\n");
 				INDENT(+1);
-				OUT("_ASN_CTFAIL(app_key, td, sptr,\n");
+				OUT("ASN__CTFAIL(app_key, td, sptr,\n");
 				OUT("\t\"%%s: value too large (%%s:%%d)\",\n");
 				OUT("\ttd->name, __FILE__, __LINE__);\n");
 				OUT("return -1;\n");
@@ -656,17 +656,17 @@ emit_value_determination_code(arg_t *arg, asn1p_expr_type_e etype, asn1cnst_rang
 		}
 		break;
 	case ASN_BASIC_REAL:
-		if(arg->flags & A1C_USE_NATIVE_TYPES) {
-			OUT("value = *(const double *)sptr;\n");
-		} else {
+		if(arg->flags & A1C_USE_WIDE_TYPES) {
 			OUT("if(asn_REAL2double(st, &value)) {\n");
 				INDENT(+1);
-				OUT("_ASN_CTFAIL(app_key, td, sptr,\n");
+				OUT("ASN__CTFAIL(app_key, td, sptr,\n");
 				OUT("\t\"%%s: value too large (%%s:%%d)\",\n");
 				OUT("\ttd->name, __FILE__, __LINE__);\n");
 				OUT("return -1;\n");
 				INDENT(-1);
 			OUT("}\n");
+		} else {
+			OUT("value = *(const double *)sptr;\n");
 		}
 		break;
 	case ASN_BASIC_BOOLEAN:
@@ -704,8 +704,8 @@ native_long_sign(asn1cnst_range_t *r) {
 	if(r->left.type == ARE_VALUE
 	&& r->left.value >= 0
 	&& r->right.type == ARE_VALUE
-	&& r->right.value > 2147483647UL
-	&& r->right.value <= 4294967295UL) {
+	&& r->right.value > 2147483647
+	&& r->right.value <= (asn1c_integer_t)(4294967295UL)) {
 		if(r->el_count == 0
 		&& r->left.value == 0
 		&& r->right.value == 4294967295UL)
