@@ -78,7 +78,7 @@ asn1c_make_identifier(enum ami_flags_e flags, asn1p_expr_t *expr, ...) {
 	 * Make sure we have this amount of storage.
 	 */
 	if(storage_size <= size) {
-		if(storage) free(storage);
+		free(storage);
 		storage = malloc(size + 1);
 		if(storage) {
 			storage_size = size;
@@ -384,7 +384,7 @@ asn1c_type_fits_long(arg_t *arg, asn1p_expr_t *expr) {
 		&& left.value >= 0
 	&& right.type == ARE_VALUE
 		&& right.value > 2147483647
-		&& right.value <= 4294967295UL)
+		&& right.value <= (asn1c_integer_t)(4294967295UL))
 		return FL_FITS_UNSIGN;
 		
 
