@@ -1,7 +1,7 @@
-#ifndef	_ASN1C_SAVE_H_
-#define	_ASN1C_SAVE_H_
+#ifndef	ASN1C_SAVE_H
+#define	ASN1C_SAVE_H
 
 int asn1c_save_compiled_output(arg_t *arg, const char *datadir,
 	int argc, int optc, char **argv);
 
-#endif	/* _ASN1C_SAVE_H_ */
+#endif	/* ASN1C_SAVE_H */
