@@ -20,9 +20,9 @@ enum asn1c_flags {
 	 */
 	A1C_OMIT_SUPPORT_CODE	= 0x0004,
 	/*
-	 * Use native data types instead of INTEGER_t et al.
+	 * Use wide types by default (INTEGER_t etc) instead of native/long.
 	 */
-	A1C_USE_NATIVE_TYPES	= 0x0008,
+	A1C_USE_WIDE_TYPES	= 0x0008,
 	/*
 	 * Do not use C99 extensions.
 	 */
@@ -60,19 +60,24 @@ enum asn1c_flags {
 	 * -gen-PER
 	 * Generate PER support code
 	 */
-	A1C_GEN_PER		= 0x1000,
+	A1C_GEN_PER			= 0x1000,
 	/*
 	 * -pdu={all|auto|Type}
 	 * Generate PDU table
 	 */
-	A1C_PDU_ALL		= 0x2000,
+	A1C_PDU_ALL			= 0x2000,
 	A1C_PDU_AUTO		= 0x4000,
 	A1C_PDU_TYPE		= 0x8000,
 	/*
 	 * -fincludes-quoted
 	 * Avoid generating #include <foo>, generate "foo" instead.
 	 */
-	A1C_INCLUDES_QUOTED	= 0x10000
+	A1C_INCLUDES_QUOTED	= 0x10000,
+	/*
+	 * -fline-refs
+	 * Include ASN.1 module's line numbers in comments.
+	 */
+	A1C_LINE_REFS       = 0x20000
 };
 
 /*
