@@ -1,17 +1,19 @@
 /*
- * Structures and prototypes related to parametrization
+ * Structures and prototypes related to parameterization
  */
-#ifndef	ASN1_PARSER_PARAMETRIZATION_H
-#define	ASN1_PARSER_PARAMETRIZATION_H
+#ifndef	ASN1_PARSER_PARAMETERIZATION_H
+#define	ASN1_PARSER_PARAMETERIZATION_H
+
+struct asn1p_expr_s;	/* Forward declaration */
 
 typedef struct asn1p_paramlist_s {
 	struct asn1p_param_s {
+		/* Translated from */
 		asn1p_ref_t	*governor;
 		char		*argument;
 	} *params;
 	int params_count;
 	int params_size;
-
 	int _lineno;
 } asn1p_paramlist_t;
 
@@ -27,4 +29,4 @@ int asn1p_paramlist_add_param(asn1p_paramlist_t *,
 		asn1p_ref_t *opt_gov, char *arg);
 
 
-#endif	/* ASN1_PARSER_PARAMETRIZATION_H */
+#endif	/* ASN1_PARSER_PARAMETERIZATION_H */
