@@ -25,10 +25,8 @@ asn1p_xports_new() {
 void
 asn1p_xports_free(asn1p_xports_t *xp) {
 	if(xp) {
-		if(xp->from)
-			free(xp->from);
-		if(xp->from_oid)
-			asn1p_oid_free(xp->from_oid);
+		free(xp->fromModuleName);
+		asn1p_oid_free(xp->identifier.oid);
 		free(xp);
 	}
 }
