@@ -1,16 +1,10 @@
-#include <OBJECT_IDENTIFIER.c>
-#include <RELATIVE-OID.c>
-#include <asn_codecs_prim.c>
-#include <ber_decoder.c>
-#include <ber_tlv_length.c>
-#include <ber_tlv_tag.c>
-#include <der_encoder.c>
-#include <xer_decoder.c>
-#include <xer_support.c>
-#include <constraints.c>
-
+#include <stdio.h>
+#include <assert.h>
 #include <sys/time.h>
 
+#include <OBJECT_IDENTIFIER.h>
+#include <RELATIVE-OID.h>
+
 static int
 _print(const void *buffer, size_t size, void *app_key) {
 	(void)app_key;
@@ -234,7 +228,8 @@ check_speed() {
 static void check_parse(const char *oid_txt, int retval) {
 	int ret;
 	long l[2];
-	const char *p;
+	const char *p = oid_txt - 13;
+	assert(p < oid_txt);
 
 	ret = OBJECT_IDENTIFIER_parse_arcs(oid_txt, -1, l, 2, &p);
 	printf("[%s] => %d == %d\n", oid_txt, ret, retval);
@@ -255,8 +250,10 @@ static void check_xer(int expect_arcs, char *xer) {
 		&asn_DEF_RELATIVE_OID, (void **)stp, "t",
 			xer, strlen(xer));
 	if(expect_arcs == -1) {
-		if(rc.code != RC_OK)
+		if(rc.code != RC_OK) {
+			printf("-1\n");
 			return;
+		}
 	}
 	assert(rc.code == RC_OK);
 
@@ -270,6 +267,7 @@ static void check_xer(int expect_arcs, char *xer) {
 	for(i = 0; i < ret; i++) {
 		if(i) printf(".");
 		printf("%ld", arcs[i]);
+		if(arcs[i] != i + 1) printf(" != %d\n", i + 1);
 		assert(arcs[i] == i + 1);
 	}
 	printf(": %d == %d\n", ret, expect_arcs);
@@ -389,15 +387,28 @@ main() {
 
 	check_parse("", 0);
 	check_parse(" ", 0);
-	check_parse(" ", 0);
 	check_parse(".", -1);
 	check_parse(" .", -1);
+	check_parse(".1", -1);
+	check_parse("1.", -1);
+	check_parse("1. ", -1);
+	check_parse(".1. ", -1);
+	check_parse(" .1. ", -1);
 	check_parse(" 1", 1);
 	check_parse(" 1.2", 2);
 	check_parse(" 1.", -1);
 	check_parse(" 1. ", -1);
 	check_parse("1. ", -1);
 	check_parse("1.2", 2);
+	check_parse("1.2 ", 2);
+	check_parse("1.2  ", 2);
+	check_parse("  1.2  ", 2);
+	check_parse("1. 2", -1);
+	check_parse("1 .2", -1);
+	check_parse(" 1 .2", -1);
+	check_parse(" 1 .2 ", -1);
+	check_parse("1 .2 ", -1);
+	check_parse("1.+1", -1);
 	check_parse("10.30.234.234", 4);
 	check_parse("10.30.234.234 ", 4);
 	check_parse("10.30.234. 234 ", -1);
@@ -406,18 +417,21 @@ main() {
 	check_parse("1.2147483647.3", 3);
 	if(sizeof(long) == 4) {
 		check_parse("1.2147483648.3", -1);	/* overflow on ILP32 */
+		check_parse("1.2147483649.3", -1);	/* overflow on ILP32 */
 		check_parse("1.3000000000.3", -1);
 		check_parse("1.4000000000.3", -1);
 		check_parse("1.5000000000.3", -1);
 		check_parse("1.6000000000.3", -1);
 		check_parse("1.9000000000.3", -1);
-	} else {
+	} else if(sizeof(long) == 8) {
 		check_parse("1.2147483648.3", 3);
+		check_parse("1.9223372036854775807.3", 3);
+		check_parse("1.9223372036854775808.3", -1);
 	}
 	check_parse("1.900a0000000.3", -1);
 	check_parse("1.900a.3", -1);
 
-	check_xer(0, "<t></t>");
+	check_xer(-1, "<t></t>");
 	check_xer(2, "<t>1.2</t>");
 	check_xer(3, "<t>1.2.3</t>");
 	check_xer(3, "<t> 1.2.3 </t>");
@@ -442,3 +456,4 @@ main() {
 
 	return 0;
 }
+
